glue\_genes.glue\_single\_cell.qt.diff\_gene\_exp.get\_gene\_diff\_exp
======================================================================

.. currentmodule:: glue_genes.glue_single_cell.qt.diff_gene_exp

.. autofunction:: get_gene_diff_exp